@@ -23,6 +23,8 @@
 #include "mongoc-read-prefs.h"
 #include "mongoc-host-list.h"
 
+BSON_BEGIN_DECLS
+
 typedef struct _mongoc_server_description_t mongoc_server_description_t;
 
 MONGOC_EXPORT (void)
@@ -49,10 +51,10 @@ MONGOC_EXPORT (const bson_t *)
 mongoc_server_description_ismaster (
    const mongoc_server_description_t *description);
 
-#ifdef MONGOC_ENABLE_COMPRESSION
 MONGOC_EXPORT (int32_t)
 mongoc_server_description_compressor_id (
    const mongoc_server_description_t *description);
-#endif
+
+BSON_END_DECLS
 
 #endif
